==> hk_cdp-1.0.32-py3-none-any.whl: hk_cdp/models/db_models/analysis/analysis_report_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-11-14 15:22:28
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class AnalysisReportModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None):
        super(AnalysisReportModel, self).__init__(AnalysisReport, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(db_config_dict)
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class AnalysisReport:
    def __init__(self):
        self.id = 0  # ID
        self.unique_id = 0  # 唯一键,根据业务md5int生成
        self.business_id = 0  # 商家标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东)
        self.store_id = 0  # 店铺标识
        self.scheme_id = 0  # 会员体系标识
        self.member_grade = 0  # 会员等级
        self.cycle_type = 2  # 周期类型(1-年 2-月 3-日)
        self.report_type = 0  # 报表类型
        self.stat_date = 0  # 统计时间
        self.report_data = {}  # 报表数据 (JSON)
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'unique_id', 'business_id', 'platform_id', 'store_id',
            'scheme_id', 'member_grade', 'cycle_type', 'report_type',
            'stat_date', 'report_data', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "analysis_report_tb"

==> hk_cdp-1.0.67-py3-none-any.whl: hk_cdp/models/db_models/analysis/analysis_report_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-01-06 10:51:42
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class AnalysisReportModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None):
        super(AnalysisReportModel, self).__init__(AnalysisReport, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(db_config_dict)
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class AnalysisReport:
    def __init__(self):
        self.id = 0  # 唯一键,根据业务md5int生成
        self.business_id = 0  # 商家标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东)
        self.store_id = 0  # 店铺标识
        self.scheme_id = 0  # 会员体系标识
        self.member_grade = 0  # 会员等级
        self.cycle_type = 2  # 周期类型(1-年 2-月 3-日)
        self.report_type = 0  # 报表类型
        self.stat_date = 0  # 统计时间
        self.report_data = {}  # 报表数据 (JSON)
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'platform_id', 'store_id',
            'scheme_id', 'member_grade', 'cycle_type', 'report_type',
            'stat_date', 'report_data', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "analysis_report_tb"
